pub struct SequentialConnector {
pub content: Arc<[String]>,
pub current: Arc<Mutex<usize>>,
}Expand description
A connector which requires you to implement the Default trait, allowing you
to determine the data it should be initialized with
Fields
content: Arc<[String]>current: Arc<Mutex<usize>>Implementations