Struct yup_hyper_mock::SequentialConnector
[−]
[src]
pub struct SequentialConnector {
pub content: Vec<String>,
// some fields omitted
}A connector which requires you to implement the Default trait, allowing you
to determine the data it should be initialized with
Fields
content: Vec<String>